summaryrefslogtreecommitdiffstats
path: root/kioslave/media/mediamanager/halbackend.h
diff options
context:
space:
mode:
Diffstat (limited to 'kioslave/media/mediamanager/halbackend.h')
-rw-r--r--kioslave/media/mediamanager/halbackend.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kioslave/media/mediamanager/halbackend.h b/kioslave/media/mediamanager/halbackend.h
index 18de7ea3c..8c8bbfce6 100644
--- a/kioslave/media/mediamanager/halbackend.h
+++ b/kioslave/media/mediamanager/halbackend.h
@@ -45,7 +45,7 @@
#include <libhal.h>
#include <libhal-storage.h>
-namespace KIO {
+namespace TDEIO {
class Job;
}
@@ -148,7 +148,7 @@ private:
static TQString killUsingProcesses(const Medium *medium);
private slots:
- void slotResult(KIO::Job *job);
+ void slotResult(TDEIO::Job *job);
/* Hal call-backs -- from gvm*/
public:
@@ -220,13 +220,13 @@ private:
const Medium* medium;
// [in,out] Should be set to true when the job completes
bool completed;
// [out] KIO::Error if an error occured during operation. Otherwise, 0
int error;
// [out] Error message to be displayed to the user
TQString errorMessage;
};
- TQMap<KIO::Job *, struct mount_job_data*> mount_jobs;
+ TQMap<TDEIO::Job *, struct mount_job_data*> mount_jobs;
};
#endif /* _HALBACKEND_H_ */
@@ -220,13 +220,13 @@ private:
// [in,out] Should be set to true when the job completes
bool completed;
- // [out] KIO::Error if an error occured during operation. Otherwise, 0
+ // [out] TDEIO::Error if an error occured during operation. Otherwise, 0
int error;
// [out] Error message to be displayed to the user